@@ -1,24 +1,24 @@
 """Parser 基类定义"""
 
-from abc import ABC
-from asyncio import Task
-from collections.abc import Callable, Coroutine
-from pathlib import Path
 from re import Match, Pattern, compile
-from typing import TYPE_CHECKING, Any, ClassVar, TypeVar, cast
+from abc import ABC
+from typing import TYPE_CHECKING, Any, TypeVar, ClassVar, cast
+from asyncio import Task
+from pathlib import Path
+from collections.abc import Callable, Coroutine
 from typing_extensions import Unpack
 
+from .data import Platform, ParseResult, ParseResultKwargs
 from ..config import pconfig as pconfig
-from ..constants import ANDROID_HEADER, COMMON_HEADER, COMMON_TIMEOUT, IOS_HEADER
-from ..constants import PlatformEnum as PlatformEnum
 from ..download import DOWNLOADER as DOWNLOADER
-from ..exception import DownloadException as DownloadException
-from ..exception import DurationLimitException as DurationLimitException
-from ..exception import ParseException as ParseException
-from ..exception import SizeLimitException as SizeLimitException
+from ..constants import IOS_HEADER, COMMON_HEADER, ANDROID_HEADER, COMMON_TIMEOUT
+from ..constants import PlatformEnum as PlatformEnum
 from ..exception import TipException as TipException
+from ..exception import ParseException as ParseException
+from ..exception import DownloadException as DownloadException
 from ..exception import ZeroSizeException as ZeroSizeException
-from .data import ParseResult, ParseResultKwargs, Platform
+from ..exception import SizeLimitException as SizeLimitException
+from ..exception import DurationLimitException as DurationLimitException
 
 T = TypeVar("T", bound="BaseParser")
 HandlerFunc = Callable[[T, Match[str]], Coroutine[Any, Any, ParseResult]]
